@@ -45,10 +45,12 @@ class ImageCreator(object):
         self.ec2 = easy_ec2
         self.host = self.ec2.get_instance(instance_id)
         if self.host.state != 'running':
-            raise exception.InstanceNotRunning(self.host.id, self.host.state,
-                                               self.host.dns_name)
-        self.host_ssh = sshutils.SSHClient(self.host.dns_name, username='root',
-                                           private_key=key_location)
+            raise exception.InstanceNotRunning(
+                self.host.id, self.host.state,
+                self.host.dns_name or self.host.private_ip_address)
+        self.host_ssh = sshutils.SSHClient(
+            self.host.dns_name or self.host.private_ip_address,
+            username='root', private_key=key_location)
         self.description = description
         self.kernel_id = kernel_id or self.host.kernel
         self.ramdisk_id = ramdisk_id or self.host.ramdisk
@@ -309,7 +311,10 @@ class EBSImageCreator(ImageCreator):
             time.sleep(5)
         while not host_ssh.path_exists(dev):
             time.sleep(5)
-        host_ssh.execute('mkfs.ext3 -F %s' % dev)
+        log.info("Formatting %s..." % vol.id)
+        host_ssh.execute('mkfs.ext3 -F %s' % dev, silent=False)
+        log.info("Setting filesystem label on %s" % dev)
+        host_ssh.execute('e2label %s /' % dev)
         mount_point = '/ebs'
         while host_ssh.path_exists(mount_point):
             mount_point += '1'
@@ -323,8 +328,8 @@ class EBSImageCreator(ImageCreator):
         fstab.close()
         log.info("Syncing root filesystem to new volume (%s)" % vol.id)
         host_ssh.execute(
-            'rsync -avx --exclude %(mpt)s --exclude /root/.ssh / %(mpt)s' %
-            {'mpt': mount_point})
+            'rsync -aqx --exclude %(mpt)s --exclude /root/.ssh / %(mpt)s' %
+            {'mpt': mount_point}, silent=False)
         log.info("Unmounting %s from %s" % (dev, mount_point))
         host_ssh.execute('umount %s' % mount_point)
         log.info("Detaching volume %s from %s" % (dev, mount_point))
@@ -340,6 +345,8 @@ class EBSImageCreator(ImageCreator):
         vol.delete()
         log.info("Creating root block device map using snapshot %s" % snap.id)
         bmap = self.ec2.create_block_device_map(root_snapshot_id=snap.id,
+                                                instance_store=True,
+                                                num_ephemeral_drives=1,
                                                 add_ephemeral_drives=True)
         log.info("Registering new image...")
         img_id = self.ec2.register_image(name=self.name,
